package com.example.ueberwachungssystem.Detection;

import android.content.Intent;
import android.os.Binder;
import android.os.IBinder;
import android.util.Log;
import android.widget.ImageView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.camera.core.ExperimentalGetImage;
import androidx.lifecycle.LifecycleService;

import com.example.ueberwachungssystem.WifiCommunication;

import java.io.File;

@ExperimentalGetImage
public class DetectorService extends LifecycleService {
    public ServiceBinder serviceBinder = new ServiceBinder();
    private DetectorService.OnDetectionListener listener;
    private boolean isServiceRunning = false;

    // Used Objects:
    public VideoDetector videoDetector = null;
    public AudioRecorder audioRecorder = null;
    public Accelerometer motionDetector = null;
    public MicrophoneDetector audioDetector = null;

    public WifiCommunication wifiCommunication;

    String wifiData;
    StringBuffer stringBufferWifi = new StringBuffer();

    String typOfAlarm;


    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        if (isServiceRunning)
            return START_NOT_STICKY;

        /** Wifi Instanz **/
        wifiCommunication = new WifiCommunication(1234);
        wifiCommunication.sendTrue("TEst");

        wifiCommunication.setOnConnectionListener(new WifiCommunication.OnConnectionListener() {
            @Override
            public void onConnection(String data) {
                Log.d("Listener", data);
                wifiData = data;
                stringToStringbuffer(data);
                Log.d("buffer",stringBufferWifi.toString());
                passToServiceListener(stringBufferWifi);
                checkState(data);
                checkTyp(data);

            }
        });





        /** Video Detection/Recorder **/
        videoDetector = new VideoDetector(this);
        videoDetector.setOnDetectionListener(new Detector.OnDetectionListener() {
            @Override
            public void onDetection(@NonNull DetectionReport detectionReport) {
                //passToServiceListener(detectionReport);
                wifiCommunication.sendTrue(detectionReport.toMessage());
            }
        });
        /** Motion Detection**/
        motionDetector = new Accelerometer(this);
        motionDetector.getSensor();
        motionDetector.setOnDetectionListener(new Detector.OnDetectionListener() {
            @Override
            public void onDetection(@NonNull DetectionReport detectionReport) {
                //passToServiceListener(detectionReport);
                wifiCommunication.sendTrue(detectionReport.toMessage());
            }
        });
        /** Audio Detection **/
        audioDetector = new MicrophoneDetector(this);
        audioDetector.setOnDetectionListener(new Detector.OnDetectionListener() {
            @Override
            public void onDetection(@NonNull DetectionReport detectionReport) {
                //passToServiceListener(detectionReport);
                wifiCommunication.sendTrue(detectionReport.toMessage());
            }
        });
        /** Audio Recorder**/
        audioRecorder = new AudioRecorder(this);






        isServiceRunning = true;
        return super.onStartCommand(intent, flags, startId);
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        isServiceRunning = false;
    }

    /** Service methods */
    public class ServiceBinder extends Binder {
        public DetectorService getBoundService() {
            // Return an instance of the TestService
            return DetectorService.this;
        }
    }
    @Nullable
    @Override
    public IBinder onBind(Intent intent) {
        super.onBind(intent);
        return serviceBinder;
    }


    /** Pass Detection Report to Service Detection Listener and trigger it */
    public void passToServiceListener(StringBuffer stringBuffer) {
        if (listener != null) {
            listener.onDetection(stringBuffer);
        }
    }


    /** On Detection Listener - runs when violation is reported */
    public interface OnDetectionListener {
        void onDetection(@NonNull StringBuffer stringBuffer);
    }
    public void setOnDetectionListener(@NonNull DetectorService.OnDetectionListener listener) {
        this.listener = listener;
    }

    public void stringToStringbuffer(String string){
        if(string != null) {
            stringBufferWifi.insert(0,string + "\n");
        }
    }

    public String[] splitString(String string){
        String[] splitrxString = string.split(",");
        return splitrxString; //splitrxString[0] = "1",splitrxString[1] = "HH:MM:SS", splitrxString[0].equals("1")

    }




    public boolean checkState(String string){
        Log.d("state", String.valueOf(splitString(string)[4].equals("An")));
        return splitString(string)[4].equals("An");
    }

    public String checkTyp(String string){
        if (splitString(string)[5] != null) {
            typOfAlarm = splitString(string)[5];
            Log.d("Type",  typOfAlarm);
        }
        return typOfAlarm;
    }
}
